#include <stdio.h>
#include <SDL.h>

#include "SDL_mixer.h"
#undef main
int main()
{

	SDL_Window* window = NULL;
	SDL_Renderer* renderer = NULL;
	SDL_Surface* tempSurface = NULL;
	SDL_Texture* texture = NULL;
	SDL_Event mainEvent;
	bool isRunning = true;

	//Sound Effect
	Mix_Chunk* chunk = NULL;
	//Background Music
	Mix_Music* music = NULL;

	//initializes  the subsystems
	if (SDL_Init(SDL_INIT_EVERYTHING) < 0)
	{
		printf("Unable to initialize SDL %s\n", SDL_GetError());
		return -1;
	}

	//Create window
	window = SDL_CreateWindow("Stdio.vn - SDL", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, 800, 640, SDL_WINDOW_SHOWN);
	if (window == NULL)
	{
		printf("Could not create window %s", SDL_GetError());
		return -1;
	}

	//create a renderer
	renderer = SDL_CreateRenderer(window, -1, SDL_RENDERER_ACCELERATED);
	if (renderer == NULL)
	{
		printf("Could not create render %s", SDL_GetError());
		return -1;
	}

	//create a tempSurface
	tempSurface = SDL_LoadBMP("background_stdio.bmp");
	//create a texutre from surface
	texture = SDL_CreateTextureFromSurface(renderer, tempSurface);
	//free surface
	SDL_FreeSurface(tempSurface);

	//Init SDL_mixer
	if (Mix_OpenAudio(44100, MIX_DEFAULT_FORMAT, 2, 2048) == -1)
	{
		printf("%s", Mix_GetError());
		return -1;
	}

	//Load Sound Effect
	chunk = Mix_LoadWAV("sound_effects.wav");
	if (chunk == NULL)
	{
		printf("%s", Mix_GetError());
		return -1;
	}

	//Load Music
	music = Mix_LoadMUS("background_music.mp3");
	if (music == NULL)
	{
		printf("%s", Mix_GetError());
	}

	//set background color
	SDL_SetRenderDrawColor(renderer, 0, 0, 0, 255);
	//main loop
	while (isRunning)
	{
		// clear the window to black
		SDL_RenderClear(renderer);
		//main event
		while (SDL_PollEvent(&mainEvent))
		{
			switch (mainEvent.type)
			{
				//User - requested quit
			case SDL_QUIT:
			{
				isRunning = false;
				break;
			}
			case SDL_KEYDOWN:
			{
				if (mainEvent.key.keysym.sym == SDLK_RETURN)
				{
					if (!Mix_PlayingMusic())
						Mix_PlayMusic(music, 0);
				}

				if (mainEvent.key.keysym.sym == SDLK_SPACE)
				{
					if (!Mix_Playing(-1))
						Mix_PlayChannel(-1, chunk, 0);
				}
				break;
			}
			default:
			{
				break;
			}
			}
		}

		// copy a portion of the texture to the current rendering target.
		SDL_RenderCopy(renderer, texture, NULL, NULL);
		//draw to the screen
		SDL_RenderPresent(renderer);
	}


	Mix_CloseAudio();
	//Destroy a window.
	SDL_DestroyWindow(window);

	//Destroy a renderer
	SDL_DestroyRenderer(renderer);

	//cleans up all initialized subsystems
	SDL_Quit();
	return 0;
}